==> 0.0.2.tar.gz: lib/src/morph_client.dart <==
import 'package:dio/dio.dart';
import 'package:meta/meta.dart';
import 'package:morph_dart/src/methods/field.dart';
import 'package:morph_dart/src/methods/group.dart';
import 'package:morph_dart/src/methods/me.dart';
import 'package:morph_dart/src/methods/record.dart';
import 'package:morph_dart/src/methods/table.dart';
import 'package:morph_dart/src/methods/team.dart';
import 'package:morph_dart/src/network/auth_token_config.dart';
import 'package:morph_dart/src/network/base_interceptor.dart';
import 'package:morph_dart/src/network/error_interceptor.dart';

class MorphClient {
  final MorphClientOptions options;

  late final Dio dio;

  late final MorphClientMethods methods;

  MorphClient(this.options) {
    final List<Interceptor> interceptors = [
      if (options.dioLog) LogInterceptor(requestBody: true),
      ErrorInterceptor(),
    ];

    dio = Dio(
      BaseOptions(
        baseUrl: options.baseUrl,
        contentType: Headers.jsonContentType,
        headers: <String, String>{
          'x-api-key': options.apiKey,
          'applicationId': options.applicationId,
        },
      ),
    )..interceptors.addAll([
        if (options.dioLog) LogInterceptor(requestBody: true),
        BaseInterceptor(interceptors, options.tokenConfig),
        ErrorInterceptor(),
      ]);

    methods = MorphClientMethods(dio);
  }
}

@immutable
class MorphClientOptions {
  final String applicationId;
  final String baseUrl;
  final String apiKey;
  final AuthTokenConfig tokenConfig;
  // TODO: Make dio config class
  final bool dioLog;

  const MorphClientOptions({
    required this.applicationId,
    required this.baseUrl,
    required this.apiKey,
    required this.tokenConfig,
    this.dioLog = false,
  });
}

class MorphClientMethods {
  late final FieldMethods field;
  late final GroupMethods group;
  late final MeMethods me;
  late final RecordMethods record;
  late final TableMethods table;
  late final TeamMethods team;

  MorphClientMethods(Dio dio) {
    field = FieldMethods(dio);
    group = GroupMethods(dio);
    me = MeMethods(dio);
    record = RecordMethods(dio);
    table = TableMethods(dio);
    team = TeamMethods(dio);
  }
}

==> 0.0.3-dev2.tar.gz: lib/src/morph_client.dart <==
import 'package:dio/dio.dart';
import 'package:meta/meta.dart';
import 'package:morph_dart/src/methods/field.dart';
import 'package:morph_dart/src/methods/group.dart';
import 'package:morph_dart/src/methods/me.dart';
import 'package:morph_dart/src/methods/record.dart';
import 'package:morph_dart/src/methods/table.dart';
import 'package:morph_dart/src/methods/team.dart';
import 'package:morph_dart/src/network/auth_token_config.dart';
import 'package:morph_dart/src/network/base_interceptor.dart';
import 'package:morph_dart/src/network/error_interceptor.dart';

class MorphClient {
  final MorphClientOptions options;

  late final Dio dio;

  late final MorphClientMethods methods;

  MorphClient(this.options) {
    final List<Interceptor> interceptors = [
      if (options.dioLog) LogInterceptor(requestBody: true),
      ErrorInterceptor(),
    ];

    dio = Dio(
      BaseOptions(
        baseUrl: options.baseUrl,
        contentType: Headers.jsonContentType,
        headers: <String, String>{
          'x-api-key': options.apiKey,
          'applicationId': options.applicationId,
        },
      ),
    )..interceptors.addAll([
        if (options.dioLog) LogInterceptor(requestBody: true),
        BaseInterceptor(interceptors, options.tokenConfig),
        ErrorInterceptor(),
      ]);

    methods = MorphClientMethods(dio);
  }
}

@immutable
class MorphClientOptions {
  final String applicationId;
  final String baseUrl;
  final String apiKey;
  final AuthTokenConfig tokenConfig;
  // TODO: Make dio config class
  final bool dioLog;

  const MorphClientOptions({
    required this.applicationId,
    required this.baseUrl,
    required this.apiKey,
    required this.tokenConfig,
    this.dioLog = false,
  });
}

class MorphClientMethods {
  final Dio dio;

  const MorphClientMethods(this.dio);

  MeMethods me() {
    return MeMethods(dio);
  }

  TeamMethods team() {
    return TeamMethods(dio);
  }

  GroupMethods group() {
    return GroupMethods(dio);
  }

  TableMethods table() {
    return TableMethods(dio);
  }

  FieldMethods field(String tableSlug) {
    return FieldMethods(dio, tableSlug);
  }

  RecordMethods<Fields> record<Fields>(
    String tableSlug,
    Object Function(Fields) toJsonFields,
    Fields Function(Object?) fromJsonFields,
  ) {
    return RecordMethods<Fields>(dio, tableSlug, toJsonFields, fromJsonFields);
  }
}
